@@ -19,22 +19,28 @@ WCF_ROOT = os.path.abspath(os.path.dirname(__file__))
 sys.path.insert(0, WCF_ROOT)
 import wcf_pb2  # noqa
 
-__version__ = "3.7.0.30.21"
+__version__ = "3.7.0.30.22"
 
 
 def _retry():
     def decorator(func):
         """ Retry the function """
         def wrapper(*args, **kwargs):
+            def logerror(e):
+                func_name = re.findall(r"func: (.*?)\n", str(args[1]))[-1]
+                logging.getLogger("WCF").error(f"Call {func_name} failed: {e}")
+
             try:
                 ret = func(*args, **kwargs)
-            except Exception as _:
+            except pynng.Timeout as _:  # 如果超时，重试
                 try:
                     ret = func(*args, **kwargs)
                 except Exception as e:
-                    func_name = re.findall(r"func: (.*?)\n", str(args[1]))[-1]
-                    logging.getLogger("WCF").error(f"Call {func_name} failed: {e}")
+                    logerror(e)
                     ret = wcf_pb2.Response()
+            except Exception as e:  # 其他异常，退出
+                logerror(e)
+                sys.exit(-1)
 
             return ret
         return wrapper
@@ -79,32 +85,40 @@ class Wcf():
             """是否文本消息"""
             return self.type == 1
 
-    def __init__(self, host_port: str = None, debug: bool = False) -> None:
+    def __init__(self, host: str = None, port: int = 10086, debug: bool = True) -> None:
         self._local_host = False
         self._is_running = False
         self._is_receiving_msg = False
         self.LOG = logging.getLogger("WCF")
         self.LOG.info(f"wcferry version: {__version__}")
-        if host_port is None:
+        self.port = port
+        self.host = host
+        if host is None:
             self._local_host = True
-            host_port = "tcp://127.0.0.1:10086"
-            cmd = f"{WCF_ROOT}/wcf.exe start {'debug' if debug else ''}"
+            self.host = "127.0.0.1"
+            cmd = f"{WCF_ROOT}/wcf.exe start {self.port} {'debug' if debug else ''}"
             if os.system(cmd) != 0:
                 self.LOG.error("初始化失败！")
-                exit(-1)
+                os._exit(-1)
+
+        self.cmd_url = f"tcp://{self.host}:{self.port}"
 
         # 连接 RPC
         self.cmd_socket = pynng.Pair1()  # Client --> Server，发送消息
         self.cmd_socket.send_timeout = 2000  # 发送 2 秒超时
         self.cmd_socket.recv_timeout = 2000  # 接收 2 秒超时
-        self.cmd_socket.dial(host_port, block=False)
+        try:
+            self.cmd_socket.dial(self.cmd_url, block=True)
+        except Exception as e:
+            self.LOG.error(f"连接失败: {e}")
+            os._exit(-2)
 
         self.msg_socket = pynng.Pair1()  # Server --> Client，接收消息
         self.msg_socket.send_timeout = 2000  # 发送 2 秒超时
         self.msg_socket.recv_timeout = 2000  # 接收 2 秒超时
-        self.msg_url = host_port.replace("10086", "10087")
+        self.msg_url = self.cmd_url.replace(str(self.port), str(self.port + 1))
 
-        atexit.register(self.cleanup)  # 退出的时候停止消息接收，防止内存泄露
+        atexit.register(self.cleanup)  # 退出的时候停止消息接收，防止资源占用
         while not self.is_login():     # 等待微信登录成功
             sleep(1)
 
@@ -395,7 +409,7 @@ class Wcf():
             if (cnt["wxid"].endswith("@chatroom")      # 群聊
                     or cnt["wxid"].startswith("gh_")       # 公众号
                     or cnt["wxid"] in not_friends.keys()   # 其他杂号
-                    ):
+                ):
                 continue
             friends.append(cnt)
 
